<?php
/**
 * Fonctions au chargement du plugin Temps de lecture
 *
 * @plugin     Temps de lecture
 * @copyright  2020
 * @author     Anne-lise Martenot
 * @licence    GNU/GPL
 * @package    SPIP\Temps_lecture\Options
 */

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

/**
 * Permet de calculer le temps de lecture du texte d'un objet donné / Voir la page de config du plugin
 *
 * @example
 * [Lecture en (#ID_ARTICLE|temps_lecture{article}) mn] -> Lecture en 4mn
 * @param intval $id_objet
 *     Identifiant de l'objet
 * @param string objet
 *     objet
 * @return intval
 *   Retourne le nombre de minutes si c'est valide, sinon rien.
 *
 **/
function temps_lecture($id_objet,$objet){
	include_spip('inc/config');
	$mots_par_minute = lire_config('temps_lecture/mots_par_minute', '250');
	$temps_lecture_objets = lire_config('temps_lecture/temps_lecture_objets', array('spip_articles'));
	
	$type_id = id_table_objet($objet); #id_article
	$table_sql = table_objet_sql($objet); #spip_articles
	
	if(intval($id_objet) AND in_array($table_sql,$temps_lecture_objets)){
		$texte = sql_getfetsel('texte', $table_sql, $type_id=intval($id_objet));
		
		$str_word_count = str_word_count( strip_tags( textebrut($texte) ) );
		
		$nb_minutes = round($str_word_count/$mots_par_minute);
				
		return $nb_minutes;
	}
	
	return false;
}

/**
 *
 * @param string $string
 * 	repertoire/fond+class	
 * @return array
 **/
function fond_class($string_plus){
	$retour = array();
	$fond = explode('+',$string_plus);
	$retour = array($fond[0],$fond[1]);
	return $retour;
}


/**
 * Pipeline recuperer_fond
 * il faut savoir sur quel fond on est
 * voir config ? : repertoire/page+class,repertoire/page+class,repertoire/page+class 
 *
 **/
function temps_lecture_recuperer_fond($flux){
	include_spip('inc/config');
	$fonds_class = lire_config('temps_lecture/fonds_class');
	$fond_class = array();
	//array multi pour les liaisons fond1+classA,fond2+classB,fond3+classC
	//si il y a plusieurs virgules
	if(strstr($fonds_class, ',')){
	$list_fonds = explode(',',$fonds_class);
		foreach ($list_fonds as $string_plus){
			$fond_class[] = fond_class($string_plus); 
		}
	} else {
		$fond_class[] = fond_class($fonds_class);
	}
	//trop lourd ?
	/*
	for ($row = 0; $row < count($fond_class); $row++) {
		spip_log("test3= nb=".count($fond_class)." avec ".$fond_class[$row][0] .' et '.$fond_class[$row][1],'temps_lecture_recuperer_fond');
	}
	*/
	
		if ($flux['args']['fond'] === 'content/article'){
			$id_objet = $flux['args']['contexte']["id_article"]; //54
			$objet =  $flux['args']['contexte']["type-page"]; //article
			$html = $flux['data']['texte']; //html du fragment
			//?$pipeline_temps_lecture = pipeline('temps_lecture', '');
			$temps_lecture = temps_lecture($id_objet,$objet);
			if($temps_lecture > 0){
				$class = "div.texte";//lire_config('temps_lecture/apres_class');
				$temps_lecture_texte = "<div class='temps_lecture'>"
				._T('temps_lecture:temps_lecture_estimation',array('temps_lecture' => $temps_lecture))
				."</div>";
				$temps_lecture_ajoute = temps_lecture_ajoute($html, $class, $temps_lecture_texte);
				$flux['data']['texte'] = $temps_lecture_ajoute;
			}
		}
	
	return $flux;
}


/**
 * réécriture dans le fragment avec insertion du texte html après la class donnée
 *
 * @param string $html  
 *		le fragment html (avec son DOM)
 * @param string 
 *		la class du tag après lequel insérer la chaine
 * @param string $temps_lecture_texte 
 *		la chaine à insérer
 * @return string
 **/
function temps_lecture_ajoute($html, $class, $temps_lecture_texte) {	
	if(isset($html) AND isset($temps_lecture_texte) AND isset($class)){
		include_spip('inc/querypath');
		$qp = QueryPath::withHTML($html);	
		$qp->find($class)->before($temps_lecture_texte)->writeHTML();
	
		//il faut un retour quelconque pour eviter une erreur 404
		return "<!--   -->";
	} else {
			return $html;
	}
}